#
# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
import os
import shutil

from . import ngasclient as nc


def ingest(sdm, ngasstagingpath):
    ingestSDM(sdm, ngasstagingpath)
    ingestBDF(sdm, ngasstagingpath)
    # ingestmetadata(sdm)


def ingestSDM(sdm, ngasstagingpath):
    for table in sdm.tables:
        filename = sdm.tables[table].entityid
        filename = filename.replace("://", "___").replace("/", "_")
        if sdm.tables[table].path.endswith(".xml"):
            extension = ".sdm"
        else:
            extension = ".bin"
        stagingfile = os.path.join(ngasstagingpath, filename) + extension
        if os.path.exists(sdm.tables[table].path):
            # For now copy, don't move file
            # shutil.move(sdm.tables[table].path, stagingfile)
            shutil.copy(sdm.tables[table].path, stagingfile)
        if os.path.isfile(stagingfile):
            nc.archivefile(stagingfile)
        else:
            print("File {} does not exist in the ngas staging area".format(stagingfile))


def ingestBDF(sdm, ngasstagingpath):
    extension = ".bdf"
    for sourcefile in sdm.bdffiles:
        destinationfile = os.path.join(ngasstagingpath, os.path.basename(sourcefile)) + extension
        if os.path.exists(sourcefile):
            shutil.copy(sourcefile, destinationfile)
        if os.path.isfile(destinationfile):
            nc.archivefile(destinationfile)
        else:
            print("File {} does not exist in the ngas staging area".format(destinationfile))


def ingestmetadata(sdm):
    # TODO
    # Add entries to the metadata db for each SDM Table and BDF ingested into NGAS
    # Add the science data to the metadata db
    print("ingesting metadata")
    # Call the model and pass it the SDM
