#
# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
import logging
from pathlib import Path

import pysftp
from pycapo import CapoConfig

LOG = logging.getLogger("ingestion")
config = CapoConfig()

KEY_FILE = str(Path.home() / ".ssh" / "scp_only")
SSH_USER = "vlapipe"
SSH_HOST = "mcilroy.aoc.nrao.edu"
OUT_DIR = config.getstring("archive-ingestion.vlass.ThumbnailPath")

# Disable the use of host keys.
cnopts = pysftp.CnOpts()
cnopts.hostkeys = None


def copy_thumbnail(source, target):
    """
    Remote copy of thumbnail images
    """
    target_path = Path(target)

    LOG.debug(f"Copying thumbnail from {source} to {target}")

    with pysftp.Connection(SSH_HOST, username=SSH_USER, private_key=KEY_FILE, cnopts=cnopts) as sftp:
        sftp.makedirs(str(target_path.parent))
        sftp.put(source, remotepath=str(target_path))
